==> common-10.3.0-811.1925-sources.jar: ai/digital/deploy/tasker/common/TaskMetadata.java <==
package ai.digital.deploy.tasker.common;


public final class TaskMetadata {
    public static final String APPLICATION = "application";
    public static final String APPLICATION_INTERNAL_ID = "application_internal_id";
    public static final String APPLICATION_SECURED_CI = "application_secured_ci";
    public static final String APPLICATION_DIRECTORY_REFERENCE = "application_directory_ref";
    public static final String VERSION = "version";
    public static final String ENVIRONMENT = "environment";
    public static final String ENVIRONMENT_ID = "environment_id";
    public static final String ENVIRONMENT_INTERNAL_ID = "environment_internal_id";
    public static final String ENVIRONMENT_SECURED_CI = "environment_secured_ci";
    public static final String ENVIRONMENT_DIRECTORY_REFERENCE = "environment_directory_ref";
    public static final String SATELLITE_IDS = "satellite_ids";
    public static final String TASK_TYPE = "taskType";
    public static final String WORKER_NAME = "worker_name";

    /// key for for control task names
    public static final String TASK_NAME = "taskName";
    public static final String TASK_LABEL = "taskLabel";
    public static final String CONTROL_TASK_TARGET_CI = "controlTaskTargetCI";
    public static final String CONTROL_TASK_TARGET_INTERNAL_CI = "controlTaskTargetInternalCI";
    public static final String CONTROL_TASK_TARGET_SECURED_CI = "controlTaskTargetSecureCI";
    public static final String CONTROL_TASK_TARGET_DIRECTORY_REFERENCE = "controlTaskTargetDirectoryRef";

    public static final String CLOUD_ENVIRONMENT_ID = "cloudEnvironmentId";
    public static final String CLOUD_ENVIRONMENT_TEMPLATE_ID = "cloudEnvironmentTemplateId";
    public static final String CLOUD_OPERATION = "cloudOperation";

    public static final String ROLLBACK_TASK = "rollbackTask";

    private TaskMetadata() {
    }

}

==> common-10.4.0-1013.1441-sources.jar: ai/digital/deploy/tasker/common/TaskMetadata.java <==
package ai.digital.deploy.tasker.common;


public final class TaskMetadata {
    public static final String APPLICATION = "application";
    public static final String APPLICATION_INTERNAL_ID = "application_internal_id";
    public static final String APPLICATION_REFERENCE_ID = "application_reference_id";
    public static final String APPLICATION_SECURED_CI = "application_secured_ci";
    public static final String APPLICATION_DIRECTORY_REFERENCE = "application_directory_ref";
    public static final String VERSION = "version";
    public static final String ENVIRONMENT = "environment";
    public static final String ENVIRONMENT_ID = "environment_id";
    public static final String ENVIRONMENT_INTERNAL_ID = "environment_internal_id";
    public static final String ENVIRONMENT_REFERENCE_ID = "environment_reference_id";
    public static final String ENVIRONMENT_SECURED_CI = "environment_secured_ci";
    public static final String ENVIRONMENT_DIRECTORY_REFERENCE = "environment_directory_ref";
    public static final String SATELLITE_IDS = "satellite_ids";
    public static final String TASK_TYPE = "taskType";
    public static final String WORKER_NAME = "worker_name";

    /// key for for control task names
    public static final String TASK_NAME = "taskName";
    public static final String TASK_LABEL = "taskLabel";
    public static final String CONTROL_TASK_TARGET_CI = "controlTaskTargetCI";
    public static final String CONTROL_TASK_TARGET_INTERNAL_CI = "controlTaskTargetInternalCI";
    public static final String CONTROL_TASK_TARGET_SECURED_CI = "controlTaskTargetSecureCI";
    public static final String CONTROL_TASK_TARGET_DIRECTORY_REFERENCE = "controlTaskTargetDirectoryRef";

    public static final String CLOUD_ENVIRONMENT_ID = "cloudEnvironmentId";
    public static final String CLOUD_ENVIRONMENT_TEMPLATE_ID = "cloudEnvironmentTemplateId";
    public static final String CLOUD_OPERATION = "cloudOperation";

    public static final String ROLLBACK_TASK = "rollbackTask";

    private TaskMetadata() {
    }

}
